bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 3. Aventiure
___________________________________________________ #### Wie si ze Wormz chomen
| ### en herren mvoten selten deheiniv herzeleit ### er horte sagen mere wie ein schoeniu meit ### were in Burgonden ze wunsche wolgetan ### von der er sit vil frovden vnd arebeit gewan
###### 46 | ### Div ir vnmazen schoene was uil witen kunt ### vnd ir hohgemvote zvo der selben stvnt ### an der iunchfrovwen so manich helt ervant ### ez ladete vil der geste in Gunthers lant
###### 47 | ### Swaz man der werbenden nach ir mine ie gesach ### Chriemhilt in ir sinne ir selber ie veriach ### daz si deheinen wolde ze truotenne han ### <er> was ir vil vremde dem si wart sider vndertan
###### 48 | ### o dacht vof hohe minne daz Siglinde kint ### z was ir aller werben wider in ein wint ### er mohte wol verdienen schoener frovwen lip ### sit wart diu edel Chriemhilt des <chuonen> Sifrides wip
###### 49 | ### Im rieten sine mage vnd ander sine man ### sit er vof stete minne tragen wolde wan ### daz eine danne wurbe div im moehte zemen ### do sprach der edel Sifrit so wil ich Chriemhilden nemen
###### 50 | ### die schoenen iungfrovwen von Burgvnden lant ### dvrch ir vnmazlich schoene daz ist mir wol bekant [3a] ### nie keiser wart so riche der wolde haben wip ### < me> wol ze minne der richen kuniginne lip
###### 51 | ### Disiu selben mære gehorte Sigmunt ### ez reiten sine lute da von wart im kvnt ### der wille sines kindes ez was im harte leit ### daz er werben wolde die vil herliche meit
###### 52 | ### Ez gefriesch ovch Siglint des edeln kuniges wip ### si hete groze sorge vmb ir kindes lip ### wan si wol erkande Gunthern vnd sine man ### den gewerbt man sere dem degne leiden began
###### 53 | ### Do sprach der kuone Sifrit vil lieber vater min ### ane edelr frovwen minne wold ich immer sin ### ich enwurbe daz min herze groze liebe hat ### swaz iemen rede kvnde des was deheinr slahte rat
###### 54 | ### Unde wildu niht erwinden sprach der kvnich do ### so bin ich dins willen werlichen vro ### vnd wil dir ze helfen enden so ich aller beste kan ### doch hat der kunich Gunther vil manigen hochuertegen man
###### 55 | ### Obe ez ander nieman were wan Hagene der degen ### der kan mit vbermvete wol hochverte pflegen ### daz ich des sere furchte ez mug vns werden leit ### ob wir werben wellen die herlichen meit
###### 56 | ### Waz mag uns gewerren sprach do Sifrit ### swaz ich frivntliche niht ab in erbit ### daz mach sus erwerben mit ellen da min hant ### ich trovwe an im erdwingen beidiv lute vnde lant
###### 57 | ### Do sprach der fvrste Sigmvnt din rede ist mir leit ### wan wurden disiv mære ze Rine geseit ### dvn doerftest nimmer geriten in Gunthers lant ### Gvnther vnde Gernot die sint mir lange bechant
###### 58 | ### Mit gewalte nieman erwerben mach die maget ### so sprach der kunich Sigmunt daz ist mir wol gesaget ### wil aber dv mit rechen riten in daz lant ### obe wir iht haben friunde die werdent schiere besant
###### 59 | ### Des ist mir niht ze mvote sprach aber Sifrit ### daz mir svlen ze Rine reken volgen mit ### dvrch deheine heruart daz wære mir vil leit ### da mit ich solde ertwingen die vil herlichen meit
###### 60 | ### Si mach wol sus ertwingen da min eins hant ### ich wil selbe zwelfter in Gvnthers lant ### dar svlt ir mir helfen vater Sigmunt ### do gap man sinen degnen ze chleidern gra vn– bunt
###### 61 | ### Do uernam ch disiu mere sin mvoter Siglint ### si begvnde troevren vmb ir liebez kint ### daz vorchte si uerliesen von Gvnthers man ### div edel kvnniginne vil sere weinen began
###### 62 | ### Sifrit der herre gie da er si sach ### wider sine mvoter er gvotlichen sprach ### frovwe ir svlt niht weinen durch den willen min ### ia wil ich ane sorge vor allen vienden sin [3b]
###### 63 | ### Vnde helfet mir der reise in Burgonden lant ### daz ich vnd mine rechen haben solch gewant ### daz also stolze rechen mit eren mvgen tragen ### des wil ich iv genade mit triwen wærlichen sagen
###### 64 | ### Sit du niht wil erwinden sprach frov Siglint ### so hilf ich dir der reise min einigez kint ### mit der besten weten die riter ie getruoch ### dir vn– dinen gesellen ir sult ir fueren genuoch
###### 65 | ### Do neich der kvniginne Sifrit der iunge man ### er sprach ich wil ze der verte niemen mere han ### niwan zwelef reken den sol man brveuen wat ### ich wil daz gerne sehen wie ez vmbe Chriemhilde stat
###### 66 | ### Do sazen schoene frovwen naht vnde tac ### daz luzel ir deheiniv ruowe gepflac ### vnze man geworhte die Sifrides wat ### er wolde siner reise haben deheiner slahte rat
###### 67 | ### Sin vater hiez im zieren sin riterlich gewant ### da mit er wolde rvmen daz Sigmundes lant ### vnd ir vil liehten bruneie die wrden ovch bereit ### vnd ir veste helmen ir schilde schoene vnde breit
###### 68 | ### Do nahte in ir reise zvo den Burgonden dan ### vmb si begvnde sorgen wip vnde man ### ob si immer komen solden heim wider in ir lant ### die helde in hiezen sovmen beide wafen vnd gewant
###### 69 | ### Ir ros div waren schoene ir gereite goldes rot ### lebte iemen vbermueter des enwas niht not ### danne wære Sifrit vnd die sine man ### vrlovbes er do gerte zuo den Burgonden dan
###### 70 | ### In werten trurichliche der kvnich vnd sin wip ### er troste minnechliche do ir beider lip ### er sprach ir svlt niht weinen durch den willen min ### immer ane sorge sult ir mins libes sin
###### 71 | ### Ez was leit den rechen ez weinte ovch manech meit ### ich wene in hete ir herze rehte daz geseit ### da von daz in so vil der friunde da uon gelege tot ### von svlden si do chlageten des gie in wærlichen not
###### 72 | ### An dem sibenden morgen ze Wormz vof den sant ### riten die uil chvonen allez ir gewant ### was von roteme golde ir gereite wol getan ### ir ros in giengen ebne des chvonen Sifrides man
###### 73 | ### Ir schilde waren niwe lieht vn– breit ### vnde vil schoene ir helmen do ze houe reit ### Sifrit der vil chuene in Gvnthers lant ### man gesach an helden nie so herlich gewant
###### 74 | ### Div ort der swerte giengen nider vof die sporn ### ez fvorten scharpe gern die riter vz erkorn ### Sifrit der fuorte ir einen wol zweier spannen breit ### der ze sinen ecken vil harte vreislichen sneit
###### 75 | ### Die goltuarben zovme fuorten si an der hant ### sidiniu wrbuege sus chomens in daz lant [4a] ### daz volch si allenthalben kaphen an began ### do liefen in enkegene vil der Gvnthers man
###### 76 | ### Die hochgemvoten rechen riter vn– chneht ### die giengen zvo den herren daz was michel reht ### vnde enphiengen die geste <in> ir herren lant ### vnd namen in die moere mit den schilden von der hant
###### 77 | ### Diu ros si wolden dannen ziehen an gemach ### Sifrit der vil chuone wie snelle er do sprach ### lat vns sten die moere mir vnde minen man ### wir wellen schiere hinnen des ich gvoten willen han
###### 78 | ### Swem sin kvnt div mere der sol mich niht verdagen ### wa ich den kvnich vinde daz sol man mir sagen ### Gvnthern den vil richen voz Burgunden lant ### do sagte ez ime einer dem ez rehte was bechant
###### 79 | ### Welt ir den kvnich vinden daz mach vil wol geschehen ### in ienen salen witen han ich in gesehen ### bi den sinen helden da sult ir hine gan ### da mvget ir bi im vinden manigen herlichen man
###### 80 | ### Nv waren deme kvnige div mere geseit ### daz da komen weren ritter wol gemeit ### die fuorten riche brunne vnd erlich gewant ### si derkanden nieman in der Burgunden lant
###### 81 | ### Den kunich nam des wunder von wannen choemen dar ### die herlichen reken in wæte lieht gevar ### vnd mit so gvoten silden niv unde breit ### daz im daz sagte nieman daz was Gunthere leit
###### 82 | ### Des antwurtete dem kvnige von Mecen Ortwin ### rivch vnde kuene mohte er vil wol sin ### sit wir ir niht erchennen so sult ir heizzen gan ### nach minem oeheim Hagnen den sult ir si sehen lan
###### 83 | ### Dem sint kvnt div riche vnd elliv vremdiu lant ### sin im die herren kunde daz tuo er uns bechant ### der kunich bat in bringen vnd die sine man ### man sach in herliche mit reken hin ze houe gan
###### 84 | ### Waz sin der kunich wolde des fragte Hagne ### ez sint in mime huose vnchvnde degne ### die niemen hie bekennet habet irs <ie> gesehen ### des solt du mir Hagne hie der warheit veriehen
###### 85 | ### Daz tuon ich sprach Hagne zvo einem venster er do gie ### sin ovgen er da wenden zuo den gesten lie ### wol behagte im ir geuerte vnd ovch ir gewant ### si waren im vil vremde in der Burgunden lant
###### 86 | ### Er sprach von wannen komen die reken an den Rin ### ez moehten fursten selbe oder fursten boten sin ### ir ros div sint schoene ir chleider harte guot ### von svannen si choment si sint helde hoch gemvot
###### 87 | ### Also sprach do Hagne ich wil des wol veriehen ### swie ich niemere Siuriden habe gesehen ### so wil ich wol gelovben swie ez darumbe stat ### daz ez si der reke der dort so herlichen gat [4b]
###### 88 | ### Er bringet niwiu mere her in dizze lant ### die kuenen Niblunge sluoch des heldes hant ### Silbunch vnd Niblungen des richen kuniges kint ### er frvmte starchiu wunder mit siner krefte sint
###### 89 | ### <Da> der helt aleine an alle helfe reit ### er vant vor einem perge als mir ist geseit ### <pei> Niblvnges horde vil manigen chvenen man ### die warn im ee vil vromde vntz er ir chvende da gewan
###### 90 | ### Der hort Niblunges der was gar getragen ### vz eime holn berge nu horet wunder sagen ### wie in wolden teilen der Niblunge man ### daz sach der degen Sifrit den helt es wndern began
###### 91 | ### Er chom zvo zim so nahen daz er die helde sach ### vnd ovch in die degne ir einr darunder sprach ### hie chumet der starke Sifrit der helt von Niderlant ### vil seltsaniv mære er an den Niblungen vant
###### 92 | ### Den reken wol enphiengen Schilbunch vnd Niblunch ### mit gemeinem rate die edelen fursten iunch ### den schaz in baten teiln den wætlichen man ### vnde gerten des mit flize der herre loben inz began
###### 93 | ### Er sach so uil gesteines so wir horen sagen ### hundert ganze wagene ez heten niht getragen ### noch me des roten goldes von Niblvnge lant ### daz solt in allez teilen des kvenen Sifrides hant
###### 94 | ### Do gaben si im ze miete daz Niblunges swert ### si waren mit dem dienste vil ubele gewert ### den in da leisten solde Sifrit der helt guot ### er enkvndez niht verenden si waren zornich gemvot
###### 95 | ### Si heten da ir friunde zwelf kuener man ### daz starke risen warn waz chvndez si ueruan ### die sluoch sit mit zorne diu Sifrides hant ### vnd reken siben hundert twang er von Niblvnge lant
###### 96 | ### mit dem guoten swerte daz hiez Balmunch ### durch die starken <vorhte> vil manich reche iunch ### die si ze dem swerte heten vnd an den kuenen man ### daz lant zuo den burgen si im taten vndertan
###### 97 | ### Dar zuo die richen kvnige die sluog er beide tot ### er chom von Albriche sit in groze not ### der wande sine herren rechen da zehant ### vnz er die grozen sterke sid ab Sifride vant
###### 98 | ### Don chvnd im niht gestriten daz starke getwerch ### alsam die lewen wilde si liefen an den perch ### da er die tarnchappe sit Albriche angewan ### do was des hordes herre Sifrit der vreisliche man
###### 99 | ### Die da torsten vehten die lagen alle erslagen ### den satz den hiez er balde fuoren vnde tragen ### da in da uor namen die Niblunges man ### Albrich der vil starke do die kameren gewan
###### 100 | ### Er muos in sweren eide er diente im so sin chneht ### aller hande dinge was er im gereht [5a] ### so sprach von Tronie Hagne daz hat er getan ### also grozer krefte nie mer reke gewan
###### 101 | ### Noch weiz ich an ime mere daz mir ist bechant ### einen lintrachen sluoch des heldes hant ### er badete sich in dem bluote sin huot wart hurnin ### des snidet in chain wafen daz ist diche worden schin
###### 102 | ### Wir sulen den iungen herren enphahen dester baz ### daz wir iht verdienen des snellen rechen haz ### sin lip der ist so schoene man sol in holden han ### er hat mit siner chrefte so manigiu wunder getan
###### 103 | ### Do sprach der kunige des landes nu si vns willechomen ### er ist edel vnde kuone daz han ich wol uernomen ### des sol er geniezen in der Bvrgonden lant ### do gie der herre Gunther da er Sifriden vant
###### 104 | ### Der wirt vnd sine geste enpfiengen so den gast ### daz in an ir zvhten vil luzel ie gebrast ### des begvnde in nigen der wetliche man ### daz si im heten gruozen so rehte schoene getan
###### 105 | ### Mich wndert diser mære sprach der kunich zehant ### von wannen ir edel Sifrit sit chomen in ditze lant ### oder waz ir wellet werben ze Wormz an den Rin ### do sprach der gast ze dem kvnige daz sol iv unverdaget sin
###### 106 | ### Mir wart gesaget mere in <mines> vater lant ### daz hie bi iv weren daz hete ich gerne bechant ### die kuonsten reken des han ich vil vernomen ### die ie kvnich gewunne darumbe bin ich her bechomen
###### 107 | ### ovch hoere iuch selben der <degenheite> iehen ### daz man kvnich deheinen chuoner habe gesehen ### des redent vil die lute vber elliv disiv lant ### nune wil üch niht erwinden vntz ez mir werde bechant
###### 108 | ### Ich bin ovch ein reche vnde solde krone tragen ### ich wil daz gerne fuege daz si von mir sagen ### daz ich habe von rehte beidiu lute vn– lant ### darumbe sol min ere vnd ovch min hovbet wesen phant
###### 109 | ### Nv ir sit so kuone als mir ist geseit ### nune ruoche <ich> ist ez ieman liep oder leit ### ich wil an iv ertwingen swaz ir muget han ### lant vnde burge daz sol mir werden vndertan
###### 110 | ### Den kunich hete wnder vnd sine man alsam ### vmbe solhiu mære als er hie uernam ### daz er des hete willen er name im siniu lant ### daz horten sine degne do wart in zvrnen bechant
###### 111 | ### Wie het ich daz uerdienet sprach Gunther der <degen> ### des min vater lange mit eren hat gepflegen ### daz wir daz solden verliesen von iemans uberchraft ### wir liezen vbel schinen daz wir ovch pflegen riterschaft
###### 112 | ### Ich ne wils niht erwinden sprach der kuone man ### ez en mvgen von dinen ellen din lant den fride han ### ich wils alles walten vnd ovch div erbe min ### erwirbest dus mit sterche div sulen dir vndertanech sin [5b]
###### 113 | ### Din erbe vnd ovch daz mine sulen geliche ligen ### sweder vnser einer an dem anderen mach gesigen ### dem sol ez allez dienen die lute vnd ovch diu lant ### daz widerredet Hagne da unde Gernor sa zehant
###### 114 | ### Wir han des niht gedingen sprach do Gernot ### daz wir iht lande ertwingen daz iemen darumbe tot ### gelige vor heldes handen wir haben richiv lant ### div dienent vns ze rehte ze niemen sint si baz bewart
###### 115 | ### Mit grimmegen mvote stuonden da die frivnde sin ### do was ovch darunder von Mecen Ortwin ### der sprach disiu suone ist mir harte leit ### iv hat der starke Sifrit vnuerdient widerseit
###### 116 | ### Ob ir vnd iwer brueder hetet niht die wer ### vnd ob er danne hete ein ganzez kvniges her ### ich trute wol erstriten daz der kuene man ### dise starche ubermvote von waren schulden muose lan
###### 117 | ### Daz zurnde harte sere der helt von Niderlant ### er sprach sich sol uermezen niht wider mich din hant ### ich bin ein chunich riche so bistv kvniges man ### ian dorften mich din zwelue mit strite nimer bestan
###### 118 | ### Nach swerten rief do sere von Mezen Ortwin ### er mohte Hagnen swester svn von Tronie vil wol sin ### daz der so lange dagte daz was dem kunige leit ### do vnderstuont ez Gernot ein riter chuone vnde gemeit
###### 119 | ### Er sprach zvo Ortwine lat iwer zurnen stan ### vns hat der herre Sifrit solhes niht getan ### wir mvgenz noch wol scheiden mit zvhten dest min rat ### vnd haben in ze frivnde daz vns noch lobelicher stat
###### 120 | ### Do sprach der starke Hagne vns mac wol wesen leit ### allen dinen degnen daz er ie gereit ### durch striten her ze Rine er soldez haben lan ### im heten mine herren solher leide niht getan
###### 121 | ### Des antwrte Sifrit der kreftige man ### muot iuch daz her Hagne daz ich gesprochen han ### so sol ich lazen chiesen daz die hende min ### wellent vil gewaltich hie ze den Bvrgonden sin
###### 122 | ### Daz sol ich eine wenden sprach aber Gernot ### allen sinen degnen reden uerbot ### iht mit ubermvote des im were leit ### do gedahte ovch Sifrit an die vil herlichen meit
###### 123 | ### Wie zeme <vns> mit iv striten sprach aber Gernot ### swaz helde nu darunder mvozen ligen tot ### wir hetens luzel eren vnd ir vil chleinen frum ### des antwrt ime do Sifrit des kuniges Sigemvndes svn
###### 124 | ### Warumbe bitet Hagne vnd ovch Ortwin ### daz er niht gahet striten mit den frivnden sin ### der er hie so manegen ze den Burgonden hat ### si mvozen rede uermiden daz was Gernotes rat
###### 125 | ### Ir sult vns wesen willechomen so sprach daz voten kint ### mit <iwern> hergesellen die mit iv komen sint ### wir svlen iuch gerne dienen ich vnde die mage min [6a] ### do hiez man den gesten senchen den Gunthers win
###### 126 | ### Do sprach der wirt des landes allez daz wir han ### geruochet irs nach ern daz si iv undertan ### vnd si mit iv geteilet lip unde guot ### do wart der herre Sifrit ein luzel sanfter gemuot
###### 127 | ### Do hiez man in behalten allez ir gewant ### die besten herberge man suohte die man vant ### Sifrides knehten man schuof in guot gemach ### den gast man sit vil gerne ze den Burgunden sach
###### 128 | ### Man bot im michel eren danach ze manigen tagen ### tusent stvnden mere danne ich iu kan gesagen ### daz hete versolt sin ellen ir svlt gelovben daz ### in sach vil lucel iemen der im wære gehaz
###### 129 | ### Sich flizen churzewile die kunige vnd ovch ir man ### so was er ie der beste swes man da began ### des enchunde im gevolgen nieman so michel was sin kraft ### so si den stein wrfen oder schuzen den schaft
###### 130 | ### Swa si bi den frovwen durch ir hofscheit ### kurzwile phlagen die riter vil gemeit ### da sach man ie vil gerne den helt von Niderlant ### er hete vof hohe minne sine sinne gewant
###### 131 | ### Swes man ie begunde des was sin lip bereit ### er truoch in sime sinne ein minnecliche meit ### vnd ovch in ein diu frovwe die er noch nie gesach ### div im in heimliche vil dike guotlichen sprach
###### 132 | ### Swenne vof deme houe wolden spilen da diu kint ### riter vnde knehte daz sach vil diche sint ### Chriemhilt durch die venster div kvniginne her ### deheiner churzwile bedorfte si in den citen mer
###### 133 | ### Wester daz si in sehe die er in herzen truoch ### da het er kurtzwile immer von genuoch ### sehen si siniv ovgen ich wil wol wizen daz ### daz im in dirre werlde nimmer kvnde werden baz
###### 134 | ### Swenner bi den helden vof dem houe stuont ### also noch die lute durch kurzewile tuont ### so stuont so minnecliche daz Siglinde kint ### daz in von herzeliebe trute manich vrowe sint
###### 135 | ### Er gedaht ovch manige zite wie sol daz geschehen ### daz ich die maget edele mit ovgen mvge sehen ### die ich von herze minne vnde lange han getan ### diu ist mir noch vil fremde des mvoz ich truorich gestan
###### 136 | ### So ie die kunige riche riten in ir lant ### so muosen ovch die rechen mit in al zehant ### da mite muost ovch Sifrit daz was den frovwen leit ### er leid ovch von ir minne dike michel arbeit
###### 137 | ### Sus wond er bi den herren daz ist alwar ### in Gunthers lande vollechlich ein iar ### daz er die minneclichen die cit nie gesach ### davon im sit vil liebe vnd leide gesach

<<< Übersicht <<< vorige Seite nächste Seite >>>